<?php
namespace App\Presenters;
use Nette,
	App\Model;
use  Nette\Application\UI;
use \Mesour\DataGrid\Grid,
	\Mesour\DataGrid\BasicGrid,
	\Mesour\DataGrid\NetteDbDataSource,
	\Mesour\DataGrid\Components\Link;
/**
 * Homepage presenter.
 */
class HomepagePresenter extends  UI\Presenter 
{
    /**
     *
     * @inject 
     * @var \App\Model\MujModel
     */
    public $muj_model; 

    protected function createComponentBasicDataGrid($name) {
        $selection = $this->muj_model->getTable('firmy');
        $source = new NetteDbDataSource($selection);        
       // $source->setPrimaryKey('id');
        $grid = new Grid($this, $name);        
        $grid->setDataSource($source); 
        $grid->setEmptyText('Tato tabulka je prázdná');
        $pager_limit = 8;
	$grid->enablePager($pager_limit);//nastaveni pageru a pocet polozek      
        //subgrid:
        $subItems = $grid->enableSubItems(); 
	$subItems->addGridItem('kontakty', 'Kontakty', $this->getSubGridKontakty())
                 ->setCallback(function(BasicGrid $sub_grid, $data) {                   
                    $selection = $this->muj_model->getKontaktySelection($data['id']);
                    $source = new NetteDbDataSource($selection);                             
                    $sub_grid->setDataSource($source);
	    });
            
        $subItems->addGridItem('pobocky', 'Pobočky', $this->getSubGridPobocky())
                ->setCallback(function (BasicGrid $sub_grid, $data){
                    $selection = $this->muj_model->getPobockySelection($data['id']); 
                    $source = new NetteDbDataSource($selection);                 
                    $sub_grid->setDataSource($source);                       
                });
                
        $subItems->addGridItem('spolecnici', 'Společníci', $this->getSubGridSpolecnici())
                ->setCallback(function (BasicGrid $sub_grid, $data){
                    $selection = $this->muj_model->getSpolecniciSelection($data['id']);
                    $source = new NetteDbDataSource($selection);
                    $source->setPrimaryKey('id');
                    $sub_grid->setDataSource($source);                         
                });
            
        //filter:
        $grid->enableFilter($this['firmaFiltr']);      
        $filtrovana = $grid->getFilterValues();        
        if(empty($filtrovana) === FALSE){
            if(isset ($filtrovana['nazev']) && !empty($filtrovana['nazev'])){
               $source->where('nazev LIKE ?','%'.$filtrovana['nazev'].'%'); 
            }
            if(isset ($filtrovana['mesto']) && !empty($filtrovana['mesto'])){
               $source->where('mesto LIKE ?','%'.$filtrovana['mesto'].'%'); 
            }            
        } 
             
        //editace
        $grid->enableEditableCells();
	$grid->onEditCell[] = $this->editColumn; 
       
        //nastaveni gridu        
	$grid->addText('nazev', 'Firma');
	$grid->addText('pravni_forma', 'Právní forma');
        $grid->addText('datum_zapisu', 'Datum zápisu');
        $grid->addNumber('pocet_zamestnancu', 'Počet zaměstnanců')
             ->setThousandsSeparator(' ');
        $grid->addNumber('zakladni_kapital', 'Základní kapitál')
	    ->setDecimals(2)
	    ->setDecimalPoint(',')
	    ->setThousandsSeparator(' ');     
        $grid->addText('ico','ičo');
        $grid->addText('dic', 'dič');
        $grid->addText('mesto','Město');
        $grid->addText('ulice', 'Ulice');
        $grid->addText('cislo_popisne','Číslo popisné');
        $grid->addText('psc', 'PSČ'); 
        $container = $grid->addContainer('akce', 'Akce')
                   ->setOrdering(FALSE);                   
        $action = $container->addActions('Akce');
        $action->addButton()
               ->setType('btn-danger')
               ->setIcon('glyphicon-trash')
               ->setConfirm('Opravdu chceš smazat vybranou firmu?')
               ->setAttribute('href', new Link(array(
	Link::HREF => 'deleteFirma!',
	Link::PARAMS => array( // musí to být array
	    'id'=>'{'. 'id'. '}' 
	)                   
        )));

    }


    public function handleDeleteFirma($id){
        $this->muj_model->getTable('firmy')->where('id = ? ', $id)->delete();
        $this->flashMessage("Informace o firmě byly smazány.",'success');
        $this->redirect('this'); 
    }


    public function createComponentFirmaFiltr() {
        $form = new UI\Form; 
        /*$firma = $this->muj_model->findAll()->fetchPairs('id', 'nazev');*/
        $form->addText('nazev', 'Firma')->setAttribute('placeholder', 'Firma'); 
        $form->addText('mesto', 'Město')->setAttribute('placeholder', 'Město');	
        $form->addSubmit('filter','Filter');
        $form->addSubmit('reset','Reset');
        return $form;
    }
    // uprava hodnot   
    public function editColumn($line_id, $column_name, $new_value) {
        $this->muj_model->getTable('firmy')->where('id = ?', $line_id)
                ->update(array($column_name=>$new_value));
    }
    //vytvořeni subgridu
    private function getSubGridKontakty() {
        $_sub_grid = new BasicGrid;
        $_sub_grid->setPrimaryKey('id');
        /*$limit_pager = 5;
        $_sub_grid->enablePager($limit_pager);*/
        $_sub_grid->setEmptyText('Tato tabulka je prázdná');
        $_sub_grid->enableEditableCells();
        $_sub_grid->onEditCell[] = $this->editCellKontakty; 
        $_sub_grid->addText('typ','Typ kontaktu')->setEditable(FALSE);
        $_sub_grid->addText('kontakt', 'Kontakt');
        $_sub_grid->addText('poznamka', 'Poznámka');
        //$_sub_grid->addText('nazev');
               
            $container = $_sub_grid->addContainer('akce', 'Akce')
                       ->setOrdering(FALSE);

            $action = $container->addActions('Akce');
            $action->addButton()
                   ->setType('btn-danger')
                   ->setIcon('glyphicon-trash')
                   ->setConfirm('Opravdu chceš smazat vybraný kontakt?')
                   ->setAttribute('href', new Link(array(
            Link::HREF => 'deleteKontakty!',
            Link::PARAMS => array( // musí to být array
                'id'=>'{'. 'id'. '}' 
            )

        ))); 

        return $_sub_grid;
    }

    public function handleDeleteKontakty($id){
        $this->muj_model->getTable('kontakty')
                ->where('id = ?' , $id)->delete();
        $this->flashMessage("Kontakt byl úspěšně smazán.", 'success');
        $this->redirect('this');
    }

    public function editCellKontakty($line_id,$column_name,$new_value){
        $this->muj_model->getTable('kontakty')
                ->where('id = ?', $line_id)
                ->update(array($column_name=>$new_value)); 
        $this-redirect('this');

    }

    private function getSubGridPobocky(){
        $_sub_grid_pobocky = new BasicGrid;
        $_sub_grid_pobocky->setPrimaryKey('id');
        $_sub_grid_pobocky->setEmptyText('Tato tabulka je prázdná');
        $_sub_grid_pobocky->enableEditableCells();
        $_sub_grid_pobocky->onEditCell[] = $this->editCellPobocky;    
        $_sub_grid_pobocky->addText('nazev','Pobočka');
        $_sub_grid_pobocky->addText('komentar', 'Poznámka');
        $_sub_grid_pobocky->addText('mesto','Město');
        $_sub_grid_pobocky->addText('ulice', 'Ulice');
        $_sub_grid_pobocky->addText('cislo_popisne', 'Číslo popisné');
        $_sub_grid_pobocky->addText('psc', 'psč');
        $container = $_sub_grid_pobocky->addContainer('akce', 'Akce')
                   ->setOrdering(FALSE);
        $action = $container->addActions('Akce');
        $action->addButton()
               ->setType('btn-danger')
               ->setIcon('glyphicon-trash')
               ->setConfirm('Opravdu chceš smazat vybranou firmu?')
               ->setAttribute('href', new Link(array(
                    Link::HREF => 'deletePobocky!',
                    Link::PARAMS => array( // musí to být array
                        'id'=>'{'. 'id'. '}' 
        )
        )));
        return $_sub_grid_pobocky;
    }

    public function handleDeletePobocky($id){
        $this->muj_model->getTable('pobocky')
                ->where('id = ?', $id)->delete();
        $this->flashMessage("Informace o pobočce byly smazány.", 'success');
        $this->redirect('this');
    }

    public function editCellPobocky($line_id, $column_name, $new_value){
        $this->muj_model->getTable('pobocky')
                ->where('id = ?', $line_id)
                ->update(array($column_name=>$new_value));
        $this->redirect('this');

    }

    private function getSubGridSpolecnici(){
        $_sub_grid_spolecnici = new BasicGrid;
        $_sub_grid_spolecnici->setPrimaryKey('id');
        $_sub_grid_spolecnici->setEmptyText('Tato tabulka je prázdná');
        $_sub_grid_spolecnici->enableEditableCells();
        $_sub_grid_spolecnici->onEditCell[] = $this->editCellSpolecnici;
        $_sub_grid_spolecnici->addText('osoba','Společník');
        $_sub_grid_spolecnici->addText('pozice','Na pozici');
        $_sub_grid_spolecnici->addText('podil','Podíl');
        $_sub_grid_spolecnici->addText('dalsi_firmy','Další firmy, ve kterých společník působí');
        $container = $_sub_grid_spolecnici->addContainer('akce', 'Akce')
                   ->setOrdering(FALSE);
        $action = $container->addActions('Akce');
        $action->addButton()
               ->setType('btn-danger')
               ->setIcon('glyphicon-trash')
               ->setConfirm('Opravdu chceš smazat vybraného společníka?')
               ->setAttribute('href', new Link(array(
                    Link::HREF => 'deleteSpolecnici!',
                    Link::PARAMS => array( // musí to být array
                        'id'=>'{'. 'id'. '}' 
        )
        )));
        return $_sub_grid_spolecnici;
    }

    public function handleDeleteSpolecnici($id){
        $this->muj_model->getTable('spolecnici')
                ->where('id = ?', $id)->delete();
        $this->flashMessage("Informace o společníkovi byla smazána.", 'success');
        $this->redirect('this');
    }

    public function editCellSpolecnici($line_id, $column_name, $new_value){
        $this->muj_model->getTable('spolecnici')
                ->where('id = ? ', $line_id)
                ->update(array($column_name => $new_value));
        $this->redirect('this');
    }

                   

 }
    

   



